
[![PyTest Status](https://travis-ci.org/a1ezzz/wasp-general.svg?branch=master)](https://travis-ci.org/a1ezzz/wasp-general)
[![Coverage Status](https://coveralls.io/repos/github/a1ezzz/wasp-general/badge.svg?branch=travis-ci)](https://coveralls.io/github/a1ezzz/wasp-general?branch=travis-ci)
[![Python Version](https://img.shields.io/pypi/pyversions/wasp-general.svg)](https://pypi.python.org/pypi/wasp-general)
[![Documentation Status](https://readthedocs.org/projects/wasp-general/badge/?version=latest)](http://wasp-general.readthedocs.io/en/latest/?badge=latest)

Documentation build status:

[![Build Status](http://jenkins.home.a1ezzz.ru/buildStatus/icon?job=wasp-general-docs)](https://github.com/a1ezzz/wasp-general)

PEP8 compliance (except W191 E266 E265 E731 and maximum length - 119):

[![Build Status](http://jenkins.home.a1ezzz.ru/buildStatus/icon?job=wasp-general-pep8)](https://github.com/a1ezzz/wasp-general)

# wasp-general

Collection of unrelated functions and classes widely used in different wasp-projects
